# 3.5.2.2 Ensure IPv6 loopback traffic is configured (Scored)
#
# Description:
# Configure the loopback interface to accept traffic. Configure all other interfaces to deny
# traffic to the loopback network (::1).
#
# Rationale:
# Loopback traffic is generated between processes on machine and is typically critical to
# operation of the system. The loopback interface is the only place that loopback network
# (::1) traffic should be seen, all other interfaces should ignore traffic on this
# network as an anti-spoofing measure.
#
# @summary 3.5.2.2 Ensure IPv6 loopback traffic is configured (Scored)
#
# @param enforced Should this rule be enforced
#
# @example
#   include secure_linux_cis::debian9::cis_3_5_2_2
class secure_linux_cis::debian9::cis_3_5_2_2 (
  Boolean $enforced = true,
) {

  if $enforced {

    firewall { '001 IPv6 accept all input to lo interface':
      chain    => 'INPUT',
      proto    => 'all',
      iniface  => 'lo',
      action   => 'accept',
      provider => 'ip6tables',
    }
    -> firewall { '002 IPv6 accept all output to lo interface':
      chain    => 'OUTPUT',
      proto    => 'all',
      outiface => 'lo',
      action   => 'accept',
      provider => 'ip6tables',
    }
    -> firewall { '003 IPv6 drop all to lo ::/0':
      chain    => 'INPUT',
      proto    => 'all',
      source   => '::1',
      action   => 'drop',
      provider => 'ip6tables',
    }

  }
}
